@@ -24,6 +24,7 @@ import demos
 import atajos
 import interfaz
 import interprete
+import municion
 from pilas.escena import Normal
 
 # Permite cerrar el programa usando CTRL+C
@@ -44,7 +45,7 @@ para iniciar y ejecutar la biblioteca.
 
 def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
             rendimiento=60, modo='detectar', gravedad=(0, -90), pantalla_completa=False,
-            permitir_depuracion=True):
+            permitir_depuracion=True, audio='phonon'):
     """
     Inicia la ventana principal del juego con algunos detalles de funcionamiento.
 
@@ -71,7 +72,7 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
     global mundo
 
     if not esta_inicializada():
-        motor = _crear_motor(usar_motor, permitir_depuracion)
+        motor = _crear_motor(usar_motor, permitir_depuracion, audio)
 
         if motor:
             mundo = Mundo(motor, ancho, alto, titulo, rendimiento, gravedad, pantalla_completa)
@@ -101,8 +102,8 @@ def iniciar_con_lanzador(ancho=640, alto=480, titulo='Pilas',
     """
     import lanzador
 
-    usar_motor, pantalla_completa = lanzador.ejecutar(imagen, titulo)
-    iniciar(ancho, alto, titulo, usar_motor, rendimiento, modo, gravedad, pantalla_completa, permitir_depuracion)
+    usar_motor, pantalla_completa, audio = lanzador.ejecutar(imagen, titulo)
+    iniciar(ancho, alto, titulo, usar_motor, rendimiento, modo, gravedad, pantalla_completa, permitir_depuracion, audio)
 
 
 def abrir_asistente():
@@ -137,7 +138,7 @@ def version():
     import pilasversion
     return pilasversion.VERSION
 
-def _crear_motor(usar_motor, permitir_depuracion):
+def _crear_motor(usar_motor, permitir_depuracion, audio):
     """Genera instancia del motor multimedia en base a un nombre.
 
     Esta es una función interna y no debe ser ejecutada
@@ -149,7 +150,7 @@ def _crear_motor(usar_motor, permitir_depuracion):
         if _usa_interprete_lanas():
             usar_motor = 'qtsugar'
 
-        motor = motor_qt.Motor(usar_motor, permitir_depuracion)
+        motor = motor_qt.Motor(usar_motor, permitir_depuracion, audio)
     else:
         print "El motor multimedia seleccionado (%s) no esta disponible" %(usar_motor)
         print "Las opciones de motores que puedes probar son 'qt', 'qtgl', 'qtwidget', 'qtsugar' y 'qtsugargl'."
@@ -166,7 +167,7 @@ def reiniciar():
     """Elimina todos los actores y vuelve al estado inicial."""
     mundo.reiniciar()
 
-def avisar(mensaje):
+def avisar(mensaje, retraso=5):
     """Emite un mensaje en la ventana principal.
 
     Este mensaje aparecerá en la parte inferior de la pantalla durante
@@ -174,7 +175,7 @@ def avisar(mensaje):
 
         >>> pilas.avisar("Use la tecla <esc> para terminar el programa")
     """
-    actores.TextoInferior(mensaje, autoeliminar=True)
+    actores.TextoInferior(mensaje, autoeliminar=True, retraso=retraso)
 
 def abrir_cargador():
     """Abre un cargador de ejemplos con varios códigos de prueba.
@@ -225,7 +226,6 @@ def almacenar_escena(escena):
 def recuperar_escena():
     mundo.gestor_escenas.recuperar_escena()
 
-
 # Representa el viejo acceso al modulo eventos, pero convierte cada uno
 # de los eventos en una referencia al evento dentro de la escena actual.
 from evento import ProxyEventos
