@@ -52,7 +52,7 @@ from puntaje import Puntaje
 from estrella import Estrella
 from caja import Caja
 from nave import Nave
-from disparo import Disparo
+from navekids import NaveKids
 from cursordisparo import CursorDisparo
 from piedra import Piedra
 from menu import Menu
@@ -76,3 +76,12 @@ from texto_inferior import TextoInferior
 from sonido import Sonido
 from personajes_rpg import Calvo
 from personajes_rpg import Maton
+from pacman import Pacman
+from fantasma import Fantasma
+from humo import Humo
+from proyectil import Bala
+from proyectil import Misil
+from proyectil import Dinamita
+from proyectil import EstrellaNinja
+from torreta import Torreta
+from ovni import Ovni
\ No newline at end of file
