@@ -13,7 +13,11 @@ import pilas
 DEMORA = 14
 
 class Menu(Actor):
-    "Representa un bloque que tiene fisica como una caja."
+    """Una lista de Opciones que se pueden seleccionar
+        :param opciones: Tupla con al menos dos elementos obligatorios (:texto:, :funcion:) y :argumentos: opcionales
+        :param x: Posicion en el eje x
+        :param y: Posicion en el eje y
+    """
 
     def __init__(self, opciones, x=0, y=0):
         self.opciones_como_actores = []
@@ -27,6 +31,17 @@ class Menu(Actor):
         # contador para evitar la repeticion de teclas
         self.activar()
 
+        # Mapeamos unas teclas para mover el menu
+        teclas = {pilas.simbolos.IZQUIERDA: 'izquierda',
+                              pilas.simbolos.DERECHA: 'derecha',
+                              pilas.simbolos.ARRIBA: 'arriba',
+                              pilas.simbolos.ABAJO: 'abajo',
+                              pilas.simbolos.SELECCION: 'boton'}
+
+        # Creamos un control personalizado
+        self.control_menu = pilas.control.Control(pilas.escena_actual(), teclas)
+
+
     def activar(self):
         self.escena.mueve_mouse.conectar(self.cuando_mueve_el_mouse)
         self.escena.click_de_mouse.conectar(self.cuando_hace_click_con_el_mouse)
@@ -38,9 +53,10 @@ class Menu(Actor):
     def crear_texto_de_las_opciones(self, opciones):
         "Genera un actor por cada opcion del menu."
 
-        for indice, (texto, funcion) in enumerate(opciones):
+        for indice, opcion in enumerate(opciones):
             y = self.y - indice * 50
-            opciones = pilas.actores.Opcion(texto, x=0, y=y, funcion_a_invocar=funcion)
+            texto, funcion, argumentos = opcion[0],opcion[1],opcion[2:]
+            opciones = pilas.actores.Opcion(texto, x=0, y=y, funcion_a_invocar=funcion, argumentos=argumentos)
 
             self.opciones_como_actores.append(opciones)
 
@@ -51,22 +67,25 @@ class Menu(Actor):
     def _verificar_opciones(self, opciones):
         "Se asegura de que la lista este bien definida."
 
+        
         for x in opciones:
-            if not isinstance(x, tuple) or len(x) != 2:
+
+            if not isinstance(x, tuple) or len(x)<2:
                 raise Exception("Opciones incorrectas, cada opcion tiene que ser una tupla.")
 
     def actualizar(self):
         "Se ejecuta de manera periodica."
 
         if self.demora_al_responder < 0:
-            if pilas.escena_actual().control.boton:
+            if self.control_menu.boton:
+                self.control_menu.limpiar()
                 self.seleccionar_opcion_actual()
                 self.demora_al_responder = DEMORA
 
-            if pilas.escena_actual().control.abajo:
+            if self.control_menu.abajo:
                 self.mover_cursor(1)
                 self.demora_al_responder = DEMORA
-            elif pilas.escena_actual().control.arriba:
+            elif self.control_menu.arriba:
                 self.mover_cursor(-1)
                 self.demora_al_responder = DEMORA
 
