@@ -10,11 +10,19 @@ import pilas
 from pilas.actores import Texto
 
 class Opcion(Texto):
+    """Un item discreto, dispara una funcion al seleccionares
+        :param texto: Etiqueta a mostrar
+        :param x: Posicion en el eje x
+        :param y: Posicion en el eje y
+        :param funcion_a_invocar: Manejador, se dispara al seleccionar la opcion
+        :param argumentos: Argumentos posicionales para :funcion_a_invocar:
+    """
 
-    def __init__(self, texto, x=0, y=0, funcion_a_invocar=None):
+    def __init__(self, texto, x=0, y=0, funcion_a_invocar=None, argumentos=None):
         Texto.__init__(self, texto, x=x, y=y)
         self.magnitud = 20
         self.funcion_a_invocar = funcion_a_invocar
+        self.argumentos = argumentos
         self.color = pilas.colores.gris
         self.z = -300
         self.centro = ("centro", "centro")
@@ -31,6 +39,6 @@ class Opcion(Texto):
         "Invoca a la funcion que tiene asociada para ejecutar."
 
         if self.funcion_a_invocar:
-            self.funcion_a_invocar()
+            self.funcion_a_invocar(*self.argumentos)
         else:
             print "Cuidado, la opcion", self, "no tiene funcion asociada."
