@@ -11,38 +11,35 @@ import pilas
 
 def ordenar_actores_por_valor_z():
     "Ordena todos los actores para que se impriman con 'z' como criterio de orden."
-    pilas.actores.todos.sort()
+    pilas.escena_actual().actores.sort()
 
 def insertar_como_nuevo_actor(actor):
     "Coloca a un actor en la lista de actores a imprimir en pantalla."
-    pilas.actores.todos.append(actor)
-    
-def eliminar_un_actor(actor):
-    try:
-        pilas.actores.todos.remove(actor)
-    except ValueError:
-        #TODO: quitar este silenciador de excepcion.
-        pass
+    pilas.escena_actual().actores.append(actor)
+    actor.escena = pilas.escena_actual()
 
 def eliminar_a_todos():
-    a_eliminar = list(pilas.actores.todos)
-    a_eliminar = a_eliminar[1:]    # evita borrar el fondo.
+    a_eliminar = pilas.escena_actual().actores[1:]    # evita borrar el fondo.
 
     for x in a_eliminar:
         x.eliminar()
 
+    pilas.escena_actual().actores = []
+
 def destruir_a_todos():
     "Elimina a los actores inmediatamente (evita que exploten o hagan algo)."
-    a_eliminar = list(pilas.actores.todos)
+    a_eliminar = pilas.escena_actual().actores
 
     for x in a_eliminar:
         x.destruir()
 
+    pilas.escena_actual().actores = []
+
 def obtener_actor_en(x, y):
     "Intenta obtener el actor mas cerca de la pantalla (z mas pequeño) en la posición (x, y)"
 
     # Busca el objeto que colisiones ordenando en sentido inverso.
-    for sprite in pilas.actores.todos[::-1]:
+    for sprite in pilas.escena_actual().actores[::-1]:
         if sprite.colisiona_con_un_punto(x, y):
             return sprite
 
