@@ -8,7 +8,8 @@
 
 import sys
 import os
-from PyQt4 import QtCore, QtGui, QtWebKit
+from PyQt4 import QtCore, QtGui, QtWebKit, QtNetwork
+import json
 
 from asistente_base import Ui_AsistenteWindow
 import pilas
@@ -29,6 +30,37 @@ class VentanaAsistente(Ui_AsistenteWindow):
         self._deshabilitar_barras_de_scroll()
         pilas.utils.centrar_ventana(main)
         self.statusbar.showMessage(u"Versión " + pilas.version())
+        self._habilitar_inspector_web()
+        self.salir_action.connect(self.salir_action, QtCore.SIGNAL("triggered()"), self.salir)
+        self._consultar_ultima_version_del_servidor()
+
+    def _consultar_ultima_version_del_servidor(self):
+        direccion = QtCore.QUrl("http://www.pilas-engine.com.ar/version.json")
+        self.manager = QtNetwork.QNetworkAccessManager(self.main)
+        self.manager.get(QtNetwork.QNetworkRequest(direccion))
+
+        self.manager.connect(self.manager, QtCore.SIGNAL("finished(QNetworkReply*)"),
+                self._cuando_termina_de_consultar_version)
+
+    def _cuando_termina_de_consultar_version(self, respuesta):
+        respuesta_como_texto = respuesta.readAll().data()
+        respuesta_como_json = json.loads(str(respuesta_como_texto))
+        version_en_el_servidor = float(respuesta_como_json['version'])
+        version_instalada = float(pilas.pilasversion.VERSION)
+
+        if version_en_el_servidor == version_instalada:
+            mensaje = "(actualizada)"
+        else:
+            mensaje = "(desactualizada: la version %.2f ya esta disponible!)" %(version_en_el_servidor)
+
+        self.statusbar.showMessage(u"Versión " + pilas.version() + " " + mensaje)
+
+
+    def _habilitar_inspector_web(self):
+        QtWebKit.QWebSettings.globalSettings()
+        settings = QtWebKit.QWebSettings.globalSettings()
+        settings.setAttribute(QtWebKit.QWebSettings.DeveloperExtrasEnabled, True)
+        settings.setAttribute(QtWebKit.QWebSettings.LocalContentCanAccessFileUrls, True)
 
     def _deshabilitar_barras_de_scroll(self):
         self.webView.page().mainFrame().setScrollBarPolicy(QtCore.Qt.Horizontal, QtCore.Qt.ScrollBarAlwaysOff)
@@ -36,15 +68,18 @@ class VentanaAsistente(Ui_AsistenteWindow):
 
     def _cargar_pagina_principal(self):
         file_path = utils.obtener_ruta_al_recurso('asistente/index.html')
+        # TODO: convierto la ruta en absoluta para que mac desde py2app
+        #       pueda interpretar correctamente las imagenes.
+        file_path = os.path.abspath(file_path)
 
         contenido = self._obtener_html(file_path)
         base_dir =  QtCore.QUrl.fromLocalFile(file_path)
-
         self.webView.setHtml(contenido, base_dir)
 
     def _obtener_html(self, file_path):
         archivo = open(file_path, "rt")
         contenido = archivo.read()
+        contenido = contenido.replace("{{VERSION_FRAME}}", """<iframe src='http://www.pilas-engine.com.ar/estadistica'></iframe>""")
         archivo.close()
         return contenido.decode('utf8')
 
@@ -81,7 +116,7 @@ class VentanaAsistente(Ui_AsistenteWindow):
 
     def _cuando_selecciona_abrir_manual(self):
         base_dir = str(QtCore.QDir.homePath())
-        ruta_al_manual = os.path.join(base_dir, 'pilas.pdf')
+        ruta_al_manual = os.path.join(base_dir, 'pilas-%s.pdf' %(pilas.version()))
 
         try:
             ruta = pilas.utils.obtener_ruta_al_recurso(ruta_al_manual)
@@ -89,14 +124,21 @@ class VentanaAsistente(Ui_AsistenteWindow):
         except IOError:
             titulo = "Error, no se encuentra el manual"
             mensaje = u"Lo siento, no se encuentra el manual en tu equipo. ¿Quieres descargarlo?"
-            respuesta = QtGui.QMessageBox.question(self.main, titulo, mensaje,
-                            QtGui.QMessageBox.Yes,
-                            QtGui.QMessageBox.No)
+            respuesta = self._consultar(self.main, titulo, mensaje)
 
             if respuesta == QtGui.QMessageBox.Yes:
                 url = "http://media.readthedocs.org/pdf/pilas/latest/pilas.pdf"
                 pilas.utils.descargar_archivo_desde_internet(self.main, url, ruta_al_manual)
 
+    def _consultar(self, parent, titulo, mensaje):
+        "Realizar una consulta usando un cuadro de dialogo."
+        return QtGui.QMessageBox.question(parent, titulo, mensaje,
+                                    QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+
+    def salir(self, *_):
+        self.main.close()
+
+
 
 
 class MainWindow(QtGui.QMainWindow):
