@@ -85,8 +85,12 @@ class Saltar(Comportamiento):
 class Avanzar(Comportamiento):
     "Desplaza al actor en la dirección y sentido indicado por una rotación."
 
-    def __init__(self, pasos, velocidad=5):
-        self.pasos = abs(pasos)
+    def __init__(self, pasos=0, velocidad=5):
+        if pasos > 0:
+            self.pasos = abs(pasos)
+        else:
+            self.pasos = pasos
+
         self.velocidad = velocidad
 
     def iniciar(self, receptor):
@@ -98,9 +102,12 @@ class Avanzar(Comportamiento):
     def actualizar(self):
         salir = False
 
-        if self.pasos - self.velocidad < 0:
-            avance = self.pasos
-            salir = True
+        if self.pasos > 0:
+            if self.pasos - self.velocidad < 0:
+                avance = self.pasos
+                salir = True
+            else:
+                avance = self.velocidad
         else:
             avance = self.velocidad
 
@@ -110,3 +117,53 @@ class Avanzar(Comportamiento):
 
         if salir:
             return True
+
+class Proyectil(Comportamiento):
+    "Hace que un actor se comporte como un proyectil."
+
+    def __init__(self, velocidad_maxima=5, aceleracion=1,
+                 angulo_de_movimiento=90, gravedad=0):
+
+        """
+        Construye el comportamiento.
+
+        :param velocidad_maxima: Velocidad máxima que alcanzará el proyectil.
+        :param aceleracion: Valor entre 0 y 1 para indicar lo rápido que acelerará el actor.
+        :param angulo_de_movimiento: Angulo en que se moverá el Actor.
+        :param gravedad: La velocidad vertical con la que caerá el actor.
+
+        """
+        self._velocidad_maxima = velocidad_maxima
+        self._aceleracion = aceleracion
+        self._angulo_de_movimiento = angulo_de_movimiento
+        self._gravedad = gravedad
+        self._vy = self._gravedad
+
+        if (self._aceleracion == 1):
+            self._velocidad = self._velocidad_maxima
+        else:
+            self._velocidad = 0
+
+    def iniciar(self, receptor):
+        self.receptor = receptor
+
+    def actualizar(self):
+
+        self._velocidad += self._aceleracion
+
+        if self._velocidad > self._velocidad_maxima:
+            self._velocidad = self._velocidad_maxima
+
+        self.mover_respecto_angulo_movimiento()
+
+    def mover_respecto_angulo_movimiento(self):
+        """ Mueve el actor hacia adelante respecto a su angulo de movimiento. """
+        rotacion_en_radianes = math.radians(-self._angulo_de_movimiento + 90)
+        dx = math.cos(rotacion_en_radianes) * self._velocidad
+        dy = math.sin(rotacion_en_radianes) * self._velocidad
+        self.receptor.x += dx
+        if self._gravedad > 0:
+            self.receptor.y += dy + self._vy
+            self._vy -= 0.1
+        else:
+            self.receptor.y += dy
