@@ -15,7 +15,7 @@ pilas.iniciar(titulo = "Memorice")
 
 # ejecuta escena actual.
 import escena_menu
-escena_menu.EscenaMenu()
+pilas.cambiar_escena(escena_menu.EscenaMenu())
 
 
 
