@@ -307,7 +307,7 @@ class Figura(object):
 
     def obtener_velocidad_lineal(self):
         # TODO: convertir a pixels
-        velocidad = self._cuerpo.GetLinearVelocity()
+        velocidad = self._cuerpo.linearVelocity
         return (velocidad.x, velocidad.y)
 
     def detener(self):
@@ -323,7 +323,16 @@ class Figura(object):
         if dy is None:
             dy = anterior_dy
 
-        self._cuerpo.SetLinearVelocity((dx, dy))
+        b2vec = self._cuerpo.linearVelocity
+        b2vec.x = dx
+        b2vec.y = dy
+
+        # Añadimos eltry, porque aparece el siguiente error:
+        # TypeError: in method 'b2Vec2___call__', argument 2 of type 'int32'
+        try:
+            self._cuerpo.linearVelocity(b2vec)
+        except:
+            pass
 
     def empujar(self, dx=None, dy=None):
         # TODO: convertir a metros???
@@ -373,7 +382,6 @@ class Circulo(Figura):
         fixture = box2d.b2FixtureDef(shape=box2d.b2CircleShape(radius=radio),
                                      density=densidad,
                                      linearDamping=amortiguacion,
-                                     fixedRotation=sin_rotacion,
                                      friction=friccion,
                                      restitution=restitucion)
 
@@ -385,8 +393,9 @@ class Circulo(Figura):
         if dinamica:
             self._cuerpo = fisica.mundo.CreateDynamicBody(position=(x, y), fixtures=fixture)
         else:
-            self._cuerpo = fisica.mundo.CreateStaticBody(position=(x, y), fixtures=fixture)
+            self._cuerpo = fisica.mundo.CreateKinematicBody(position=(x, y), fixtures=fixture)
 
+        self._cuerpo.fixedRotation = sin_rotacion
 
 class Rectangulo(Figura):
     """Representa un rectángulo que puede colisionar con otras figuras.
@@ -419,7 +428,6 @@ class Rectangulo(Figura):
         fixture = box2d.b2FixtureDef(shape=box2d.b2PolygonShape(box=(ancho/2, alto/2)),
                                      density=densidad,
                                      linearDamping=amortiguacion,
-                                     fixedRotation=sin_rotacion,
                                      friction=friccion,
                                      restitution=restitucion)
 
@@ -431,7 +439,9 @@ class Rectangulo(Figura):
         if dinamica:
             self._cuerpo = fisica.mundo.CreateDynamicBody(position=(x, y), fixtures=fixture)
         else:
-            self._cuerpo = fisica.mundo.CreateStaticBody(position=(x, y), fixtures=fixture)
+            self._cuerpo = fisica.mundo.CreateKinematicBody(position=(x, y), fixtures=fixture)
+
+        self._cuerpo.fixedRotation = sin_rotacion
 
         """
         bodyDef = box2d.b2BodyDef()
