@@ -14,6 +14,7 @@ from pilas.interfaz.base_interfaz import BaseInterfaz
 
 
 class Deslizador(BaseInterfaz):
+    """Representa un deslizador (slider) tipo volumen horizontal."""
 
     def __init__(self, x=0, y=0, ruta_barra = 'interfaz/barra.png',
                                  ruta_deslizador = 'interfaz/deslizador.png'):
@@ -23,9 +24,9 @@ class Deslizador(BaseInterfaz):
         self.deslizador = Actor(ruta_deslizador, self.x, self.y)
         self.deslizador.fijo = True
         self.centro = ('izquierda', 'centro')
-        
+
         self.click = False
-        
+
         self.escena.click_de_mouse.conectar(self.click_del_mouse)
         self.escena.mueve_mouse.conectar(self.movimiento_del_mouse)
         self.escena.termina_click.conectar(self.termino_del_click)
@@ -53,7 +54,7 @@ class Deslizador(BaseInterfaz):
             self.deslizador.definir_posicion(x + self.posicion_relativa_x, y)
 
     def conectar(self, f):
-        self.funciones.append(f)        
+        self.funciones.append(f)
 
     def desconectar(self, f):
         self.funciones.remove(f)
@@ -61,7 +62,7 @@ class Deslizador(BaseInterfaz):
     def ejecutar_funciones(self, valor):
         for i in self.funciones:
             i(valor)
-    
+
     def click_del_mouse(self, click):
         if (self.activo):
             if self.deslizador.colisiona_con_un_punto(click.x, click.y):
@@ -71,25 +72,25 @@ class Deslizador(BaseInterfaz):
         if (self.activo):
             if self.click == True:
                 ancho = self.obtener_ancho()
-                factor = (self.deslizador.x + (ancho - abs(self.x))) / ancho - 1
+                deslizador_pos_x = self.deslizador.x - self.x
+                factor = (deslizador_pos_x + ancho) / ancho - 1
                 self.progreso = factor
-                
+
                 self.ejecutar_funciones(factor)
-    
+
                 self.deslizador.x = movimiento.x
-    
+
                 if self.deslizador.x <= self.limite_izq:
                     self.deslizador.x = self.limite_izq
-    
+
                 elif self.deslizador.x >= self.limite_der:
                     self.deslizador.x = self.limite_der
-    
+
                 self.posicion_relativa_x = self.deslizador.x - self.x
-                
 
     def termino_del_click(self, noclick):
         self.click = False
-        
+
     def mostrar(self):
         BaseInterfaz.mostrar(self)
         self.deslizador.transparencia = 0
@@ -97,3 +98,8 @@ class Deslizador(BaseInterfaz):
     def ocultar(self):
         BaseInterfaz.ocultar(self)
         self.deslizador.transparencia = 100
+
+    def eliminar(self):
+        self.deslizador.eliminar()
+        BaseInterfaz.eliminar(self)
+
