@@ -6,7 +6,7 @@
 #
 # Website - http://www.pilas-engine.com.ar
 
-from PyQt4 import QtCore, QtGui, phonon
+from PyQt4 import QtCore, QtGui
 from PyQt4.QtCore import Qt
 from PyQt4.QtOpenGL import QGLWidget
 from pilas import actores, colores, depurador, eventos, fps
@@ -139,11 +139,16 @@ class CanvasWidget(QGLWidget):
     def mouseMoveEvent(self, e):
         escala = self.escala
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
+
         dx, dy = x - self.mouse_x, y - self.mouse_y
 
         izquierda, derecha, arriba, abajo = utils.obtener_bordes()
-        x = max(min(derecha, x), izquierda)
-        y = max(min(arriba, y), abajo)
+
+        #x = max(min(derecha, x), izquierda)
+        #y = max(min(arriba, y), abajo)
+
+        x += pilas.mundo.motor.camara_x
+        y += pilas.mundo.motor.camara_y
 
         self.gestor_escenas.escena_actual().mueve_mouse.emitir(x=x, y=y, dx=dx, dy=dy)
 
@@ -176,14 +181,22 @@ class CanvasWidget(QGLWidget):
     def mousePressEvent(self, e):
         escala = self.escala
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
+        boton_pulsado = e.button()
 
-        self.gestor_escenas.escena_actual().click_de_mouse.emitir(x=x, y=y, dx=0, dy=0)
+        x += pilas.mundo.motor.camara_x
+        y += pilas.mundo.motor.camara_y
+
+        self.gestor_escenas.escena_actual().click_de_mouse.emitir(x=x, y=y, dx=0, dy=0, boton=boton_pulsado)
 
     def mouseReleaseEvent(self, e):
         escala = self.escala
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
+        boton_pulsado = e.button()
 
-        self.gestor_escenas.escena_actual().termina_click.emitir(x=x, y=y, dx=0, dy=0)
+        x += pilas.mundo.motor.camara_x
+        y += pilas.mundo.motor.camara_y
+
+        self.gestor_escenas.escena_actual().termina_click.emitir(x=x, y=y, dx=0, dy=0, boton=boton_pulsado)
 
     def _obtener_codigo_de_tecla_normalizado(self, tecla_qt):
         teclas = {
@@ -191,7 +204,7 @@ class CanvasWidget(QGLWidget):
             QtCore.Qt.Key_Right: simbolos.DERECHA,
             QtCore.Qt.Key_Up: simbolos.ARRIBA,
             QtCore.Qt.Key_Down: simbolos.ABAJO,
-            QtCore.Qt.Key_Space: simbolos.SELECCION,
+            QtCore.Qt.Key_Space: simbolos.ESPACIO,
             QtCore.Qt.Key_Return: simbolos.SELECCION,
             QtCore.Qt.Key_F1: simbolos.F1,
             QtCore.Qt.Key_F2: simbolos.F2,
@@ -691,10 +704,58 @@ class Actor(BaseActor):
                 escala_x, escala_y, self._rotacion, self._transparencia)
 
 
-class Sonido:
+## Backend: audio deshabilitado
+
+class SonidoDeshabilitado:
+    deshabilitado = True
+
+    def __init__(self, player, ruta):
+        pass
+
+    def reproducir(self):
+        pass
+
+    def detener(self):
+        pass
+
+class MusicaDeshabilitada(SonidoDeshabilitado):
+
+    def __init__(self, media, ruta):
+        SonidoDeshabilitado.__init__(self, media, ruta)
+
+## Backend: gstreamer
+
+class SonidoGST:
+    deshabilitado = False
+
+    def __init__(self, player, ruta):
+        self.ruta = ruta
+        self.sonido = player
+        self.sonido.set_property('uri','file://'+ruta)
+
+    def reproducir(self):
+        import gst
+        if not self.deshabilitado:
+            self.sonido.set_state(gst.STATE_NULL)
+            self.sonido.set_state(gst.STATE_PLAYING)
+
+    def detener(self):
+        import gst
+        self.sonido.set_state(gst.STATE_NULL)
+
+
+class MusicaGST(SonidoGST):
+
+    def __init__(self, media, ruta):
+        SonidoGST.__init__(self, media, ruta)
+
+## Backend: audio phonon
+
+class SonidoPhonon:
     deshabilitado = False
 
     def __init__(self, media, ruta):
+        from PyQt4 import phonon
         self.media = media
         self.ruta = ruta
 
@@ -709,11 +770,10 @@ class Sonido:
     def detener(self):
         self.sonido.stop()
 
-
-class Musica(Sonido):
+class MusicaPhonon(SonidoPhonon):
 
     def __init__(self, media, ruta):
-        Sonido.__init__(self, media, ruta)
+        SonidoPhonon.__init__(self, media, ruta)
 
 
 class Motor(object):
@@ -727,7 +787,7 @@ class Motor(object):
     el dibujado en pantalla si la tarjeta de video lo soporta.
     """
 
-    def __init__(self, usar_motor, permitir_depuracion):
+    def __init__(self, usar_motor, permitir_depuracion, audio):
         if usar_motor not in ['qtwidget', 'qtsugar']:
             self._iniciar_aplicacion()
 
@@ -737,7 +797,7 @@ class Motor(object):
         self.permitir_depuracion = permitir_depuracion
 
         self._inicializar_variables()
-        self._inicializar_sistema_de_audio()
+        self._inicializar_sistema_de_audio(audio)
 
     def _iniciar_aplicacion(self):
         self.app = QtGui.QApplication([])
@@ -747,10 +807,38 @@ class Motor(object):
         self.camara_x = 0
         self.camara_y = 0
 
-    def _inicializar_sistema_de_audio(self):
-        self.media = phonon.Phonon.MediaObject()
-        self.audio = phonon.Phonon.AudioOutput(phonon.Phonon.MusicCategory)
-        self.path = phonon.Phonon.createPath(self.media, self.audio)
+    def _inicializar_sistema_de_audio(self, audio):
+        sistemas_de_sonido = ['deshabilitado', 'phonon', 'gst']
+
+        if audio not in sistemas_de_sonido:
+            error = "El sistema de audio '%s' es invalido" %(audio)
+            sugerencia = ". Use alguno de los siguientes: %s" %(str(sistemas_de_sonido))
+            raise Exception(error + sugerencia)
+
+        if audio == 'gst':
+            try:
+                import gst
+            except ImportError:
+                print "Nota: El sistema de audio gstreamer no está disponible, usando phonon en su lugar."
+                audio = 'phonon'
+
+        if audio == 'deshabilitado':
+            self.player = None
+            self.clase_sonido = SonidoDeshabilitado
+            self.clase_musica = MusicaDeshabilitada
+        elif audio == 'phonon':
+            from PyQt4 import phonon
+            self.media = phonon.Phonon.MediaObject()
+            self.audio = phonon.Phonon.AudioOutput(phonon.Phonon.MusicCategory)
+            self.path = phonon.Phonon.createPath(self.media, self.audio)
+            self.player = self.media
+            self.clase_sonido = SonidoPhonon
+            self.clase_musica = MusicaPhonon
+        elif audio == 'gst':
+            import gst
+            self.player = gst.element_factory_make("playbin", "player")
+            self.clase_sonido = SonidoGST
+            self.clase_musica = MusicaGST
 
     def terminar(self):
         self.ventana.close()
@@ -845,16 +933,16 @@ class Motor(object):
         return Grilla(ruta, columnas, filas)
 
     def cargar_sonido(self, ruta):
-        return Sonido(self.media, ruta)
+        return self.clase_sonido(self.player, ruta)
 
     def cargar_musica(self, ruta):
-        return Musica(self.media, ruta)
+        return Musica(self.player, ruta)
 
     def deshabilitar_sonido(self, estado=True):
-        Sonido.deshabilitado = estado
+        self.clase_sonido.deshabilitado = estado
 
     def deshabilitar_musica(self, estado=True):
-        Musica.deshabilitado = estado
+        self.clase_musica.deshabilitado = estado
 
     def cargar_imagen(self, ruta):
         return Imagen(ruta)
