@@ -5,13 +5,13 @@
 # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
 #
 # Website - http://www.pilas-engine.com.ar
+from __future__ import division
 import os
 import interpolaciones
 import sys
 import subprocess
 import math
 import uuid
-
 import pilas
 
 
@@ -73,6 +73,16 @@ def distancia_entre_dos_puntos((x1, y1), (x2, y2)):
 def distancia_entre_dos_actores(a, b):
     return distancia_entre_dos_puntos((a.x, a.y), (b.x, b.y))
 
+def actor_mas_cercano_al_actor(actor):
+    actor_mas_cercano = None
+    distancia = 999999
+    for actor_cercano in pilas.escena_actual().actores:
+        if id(actor_cercano) != id(actor):
+            if distancia_entre_dos_actores(actor,actor_cercano) < distancia:
+                actor_mas_cercano = actor_cercano
+
+    return actor_mas_cercano
+
 def colisionan(a, b):
     "Retorna True si dos actores estan en contacto."
     return distancia_entre_dos_actores(a, b) < a.radio_de_colision + b.radio_de_colision
@@ -93,9 +103,9 @@ def interpolable(f):
             duracion = 1
 
         if isinstance(value, list):
-            value = interpolar(value, duracion=duracion)
+            value = interpolar(value, duracion=duracion, tipo='lineal')
         elif isinstance(value, xrange):
-            value = interpolar(list(value), duracion=duracion)
+            value = interpolar(list(value), duracion=duracion, tipo='lineal')
 
         if es_interpolacion(value):
             value.apply(args[0], function=f.__name__)
@@ -136,6 +146,15 @@ def convertir_de_posicion_fisica_relativa(x, y):
     dx, dy = pilas.mundo.motor.centro_fisico()
     return (x - dx, dy - y)
 
+def calcular_tiempo_en_recorrer(distancia_en_pixeles, velocidad):
+    """ Calcula el tiempo que se tardará en recorrer una distancia en 
+    pixeles con una velocidad constante """
+
+    if (pilas.mundo.motor.canvas.fps.cuadros_por_segundo_numerico > 0):
+        return (distancia_en_pixeles / (pilas.mundo.motor.canvas.fps.cuadros_por_segundo_numerico * velocidad))        
+    else:
+        return 0
+
 def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
     """Retorna un objeto que representa cambios de atributos progresivos.
 
@@ -157,9 +176,15 @@ def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
 
     algoritmos = {
             'lineal': interpolaciones.Lineal,
+            'aceleracion_gradual': interpolaciones.AceleracionGradual,
+            'desaceleracion_gradual': interpolaciones.DesaceleracionGradual,
+            'rebote_inicial': interpolaciones.ReboteInicial,
+            'rebote_final': interpolaciones.ReboteFinal,
+            'elastico_inicial': interpolaciones.ElasticoInicial,
+            'elastico_final': interpolaciones.ElasticoFinal
             }
 
-    if algoritmos.has_key('lineal'):
+    if algoritmos.has_key(tipo):
         clase = algoritmos[tipo]
     else:
         raise ValueError("El tipo de interpolacion %s es invalido" %(tipo))
@@ -170,6 +195,22 @@ def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
 
     return clase(valor_o_valores, duracion, demora)
 
+
+def deneter_interpolacion(objeto, propiedad):
+    """ Deteiene una interpolación iniciada en un campo de un objeto.
+
+        param: objeto: Actor del que se desea detener al interpolacion.
+        para: propiedad: Cadena de texto que indica la propiedad del objeto cuya interpolación se desea terminar.
+
+       >>> pilas.utils.deneter_interpolacion(actor, 'y')
+    """
+    setter = 'set_' + propiedad
+    try:
+        getattr(objeto, setter)
+        pilas.escena_actual().tweener.removeTweeningFromObjectField(objeto, setter)
+    except:
+        print "El obejto %s no tiene esa propiedad %s" %(objeto.__class__.__name__, setter)
+
 def obtener_area():
     "Retorna el area que ocupa la ventana"
     return pilas.mundo.motor.obtener_area()
@@ -265,3 +306,11 @@ def imprimir_todos_los_eventos():
             print "Evento:", attributo.nombre
             attributo.imprimir_funciones_conectadas()
             print ""
+
+def habilitar_depuracion():
+    """Permite habilitar un breakpoint para depuracion una vez inicializado pilas."""
+    from PyQt4.QtCore import pyqtRemoveInputHook
+    from pdb import set_trace
+    pyqtRemoveInputHook()
+    set_trace()
+
